.. toctree::
   :maxdepth: 1

Sliding Puzzle Documentation
============================

.. automodule:: slidingpuzzle
   :members:
   :undoc-members:

Submodules
----------

slidingpuzzle.heuristics module
-------------------------------

.. automodule:: slidingpuzzle.heuristics
   :members:
   :undoc-members:

slidingpuzzle.slidingpuzzle module
----------------------------------

.. automodule:: slidingpuzzle.slidingpuzzle
   :members:
   :undoc-members:

slidingpuzzle.state module
--------------------------

.. automodule:: slidingpuzzle.state
   :members:
   :undoc-members:
